@@ -3,6 +3,7 @@
 
 #include <QLabel>
 #include <QMouseEvent>
+#include <QTimer>
 
 using namespace Qt;
 
@@ -16,6 +17,12 @@ public:
         void enterEvent(QEvent* eve );
         void leaveEvent(QEvent* eve );
 
+private:
+        QTimer *timer;
+
+    private slots:
+        void timeout();
+
 signals:
         void leftButtonPressed(ClickableImage* sender);
         void rightButtonPressed(ClickableImage* sender);
@@ -23,6 +30,7 @@ signals:
         void leftButtonReleased(ClickableImage* sender);
         void rightButtonReleased(ClickableImage* sender);
         void middleButtonReleased(ClickableImage* sender);
+        void leftButtonHold(ClickableImage* sender);
         void mouseEntered(ClickableImage* sender );
         void mouseLeft(ClickableImage* sender);
 };
